==> qtjambi-remoteobjects-debuginfo-macos-5.15.17.jar: sources/QtJambiRemoteObjects/QRemoteObjectPendingCall_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtRemoteObjects/qremoteobjectpendingcall.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QRemoteObjectPendingCall(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QRemoteObjectPendingCall")
    QRemoteObjectPendingCall *_ptr = reinterpret_cast<QRemoteObjectPendingCall *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QRemoteObjectPendingCall_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QRemoteObjectPendingCall *__qt_this = new(__qtjambi_ptr) QRemoteObjectPendingCall();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new 
void __qt_construct_QRemoteObjectPendingCall_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    jobject other0 = __java_arguments[0].l;
    const QRemoteObjectPendingCall& __qt_other0 = qtjambi_cast<const QRemoteObjectPendingCall& >(__jni_env, other0);
    QRemoteObjectPendingCall *__qt_this = new(__qtjambi_ptr) QRemoteObjectPendingCall(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QRemoteObjectPendingCall
void __qt_destruct_QRemoteObjectPendingCall(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QRemoteObjectPendingCall")
    reinterpret_cast<QRemoteObjectPendingCall*>(ptr)->~QRemoteObjectPendingCall();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QRemoteObjectPendingCall::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_initialize_1native__Lio_qt_remoteobjects_QRemoteObjectPendingCall_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRemoteObjectPendingCall::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QRemoteObjectPendingCall_0, sizeof(QRemoteObjectPendingCall), typeid(QRemoteObjectPendingCall), false, &deleter_QRemoteObjectPendingCall, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QRemoteObjectPendingCall::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_initialize_1native__Lio_qt_remoteobjects_QRemoteObjectPendingCall_2Lio_qt_remoteobjects_QRemoteObjectPendingCall_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRemoteObjectPendingCall::")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QRemoteObjectPendingCall_1, sizeof(QRemoteObjectPendingCall), typeid(QRemoteObjectPendingCall), false, &deleter_QRemoteObjectPendingCall, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QRemoteObjectPendingCall::error()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_error_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QRemoteObjectPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QRemoteObjectPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRemoteObjectPendingCall::error()const", __qt_this)
        QRemoteObjectPendingCall::Error __qt_return_value = __qt_this->QRemoteObjectPendingCall::error();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRemoteObjectPendingCall::isFinished()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_isFinished_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QRemoteObjectPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QRemoteObjectPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRemoteObjectPendingCall::isFinished()const", __qt_this)
        __java_return_value = __qt_this->QRemoteObjectPendingCall::isFinished();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRemoteObjectPendingCall::operator=(QRemoteObjectPendingCall)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_assign_1native_1cref_1QRemoteObjectPendingCall__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    QTJAMBI_TRY {
        QRemoteObjectPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QRemoteObjectPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRemoteObjectPendingCall::operator=(QRemoteObjectPendingCall)", __qt_this)
        const QRemoteObjectPendingCall& __qt_other0 = QtJambiAPI::interfaceReferenceFromNativeId<QRemoteObjectPendingCall>(__jni_env, other0);
        __qt_this->QRemoteObjectPendingCall::operator=(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QRemoteObjectPendingCall::returnValue()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_returnValue_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QRemoteObjectPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QRemoteObjectPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRemoteObjectPendingCall::returnValue()const", __qt_this)
        QVariant __qt_return_value = __qt_this->QRemoteObjectPendingCall::returnValue();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRemoteObjectPendingCall::waitForFinished(int)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_waitForFinished_1native_1int__JI)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jint timeout0)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QRemoteObjectPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QRemoteObjectPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRemoteObjectPendingCall::waitForFinished(int)", __qt_this)
        __java_return_value = __qt_this->QRemoteObjectPendingCall::waitForFinished(static_cast<int>(timeout0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRemoteObjectPendingCall::fromCompletedCall(QVariant)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_fromCompletedCall__Ljava_lang_Object_2)
(JNIEnv *__jni_env,
 jclass,
 jobject returnValue0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRemoteObjectPendingCall::fromCompletedCall(QVariant)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QVariant  __qt_returnValue0 = qtjambi_cast<QVariant >(__jni_env, returnValue0);
        QRemoteObjectPendingCall __qt_return_value = QRemoteObjectPendingCall::fromCompletedCall(__qt_returnValue0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_clone_1native)
(JNIEnv *__jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QRemoteObjectPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QRemoteObjectPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QRemoteObjectPendingCall(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceValueTypeInfo<QRemoteObjectPendingCall>("QRemoteObjectPendingCall", "io/qt/remoteobjects/QRemoteObjectPendingCall");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QRemoteObjectPendingCall, {
        ConstructorInfo(&__qt_construct_QRemoteObjectPendingCall_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QRemoteObjectPendingCall_1, "Lio/qt/remoteobjects/QRemoteObjectPendingCall;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QRemoteObjectPendingCall);
    registerMetaType<QRemoteObjectPendingCall>("QRemoteObjectPendingCall");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QRemoteObjectPendingCall::Error>("QRemoteObjectPendingCall::Error", "io/qt/remoteobjects/QRemoteObjectPendingCall$Error");
// END: enums and flags
}

==> qtjambi-remoteobjects-debuginfo-macos-6.7.3.jar: sources/QtJambiRemoteObjects/QRemoteObjectPendingCall_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtRemoteObjects/qremoteobjectpendingcall.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QRemoteObjectPendingCall(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QRemoteObjectPendingCall")
    QRemoteObjectPendingCall *_ptr = reinterpret_cast<QRemoteObjectPendingCall *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QRemoteObjectPendingCall()
void __qt_construct_QRemoteObjectPendingCall(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QRemoteObjectPendingCall()")
    Q_UNUSED(__java_arguments)
    QRemoteObjectPendingCall *__qt_this = new(__qtjambi_ptr) QRemoteObjectPendingCall();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QRemoteObjectPendingCall::QRemoteObjectPendingCall()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_initialize_1native__Lio_qt_remoteobjects_QRemoteObjectPendingCall_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRemoteObjectPendingCall::QRemoteObjectPendingCall()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QRemoteObjectPendingCall, sizeof(QRemoteObjectPendingCall), typeid(QRemoteObjectPendingCall), 0, false, &deleter_QRemoteObjectPendingCall, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QRemoteObjectPendingCall(QRemoteObjectPendingCall)
void __qt_construct_QRemoteObjectPendingCall_cref_QRemoteObjectPendingCall(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QRemoteObjectPendingCall(QRemoteObjectPendingCall)")
    jobject other0 = __java_arguments[0].l;
    const QRemoteObjectPendingCall& __qt_other0 = qtjambi_cast<const QRemoteObjectPendingCall&>(__jni_env, other0);
    QRemoteObjectPendingCall *__qt_this = new(__qtjambi_ptr) QRemoteObjectPendingCall(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QRemoteObjectPendingCall::QRemoteObjectPendingCall(QRemoteObjectPendingCall)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_initialize_1native__Lio_qt_remoteobjects_QRemoteObjectPendingCall_2Lio_qt_remoteobjects_QRemoteObjectPendingCall_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRemoteObjectPendingCall::QRemoteObjectPendingCall(QRemoteObjectPendingCall)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QRemoteObjectPendingCall_cref_QRemoteObjectPendingCall, sizeof(QRemoteObjectPendingCall), typeid(QRemoteObjectPendingCall), 0, false, &deleter_QRemoteObjectPendingCall, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QRemoteObjectPendingCall
void __qt_destruct_QRemoteObjectPendingCall(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QRemoteObjectPendingCall")
    reinterpret_cast<QRemoteObjectPendingCall*>(ptr)->~QRemoteObjectPendingCall();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QRemoteObjectPendingCall::error()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_error_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QRemoteObjectPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QRemoteObjectPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRemoteObjectPendingCall::error()const", __this_nativeId)
        QRemoteObjectPendingCall::Error __qt_return_value = __qt_this->QRemoteObjectPendingCall::error();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRemoteObjectPendingCall::isFinished()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_isFinished_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QRemoteObjectPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QRemoteObjectPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRemoteObjectPendingCall::isFinished()const", __this_nativeId)
        __java_return_value = __qt_this->QRemoteObjectPendingCall::isFinished();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRemoteObjectPendingCall::operator=(QRemoteObjectPendingCall)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_assign_1native_1cref_1QRemoteObjectPendingCall__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    QTJAMBI_TRY {
        QRemoteObjectPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QRemoteObjectPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRemoteObjectPendingCall::operator=(QRemoteObjectPendingCall)", __this_nativeId)
        const QRemoteObjectPendingCall& __qt_other0 = QtJambiAPI::interfaceReferenceFromNativeId<QRemoteObjectPendingCall>(__jni_env, other0);
        __qt_this->QRemoteObjectPendingCall::operator=(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QRemoteObjectPendingCall::returnValue()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_returnValue_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QRemoteObjectPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QRemoteObjectPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRemoteObjectPendingCall::returnValue()const", __this_nativeId)
        QVariant __qt_return_value = __qt_this->QRemoteObjectPendingCall::returnValue();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRemoteObjectPendingCall::waitForFinished(int)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_waitForFinished_1native_1int__JI)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jint timeout0)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QRemoteObjectPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QRemoteObjectPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QRemoteObjectPendingCall::waitForFinished(int)", __this_nativeId)
        __java_return_value = __qt_this->QRemoteObjectPendingCall::waitForFinished(static_cast<int>(timeout0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QRemoteObjectPendingCall::fromCompletedCall(QVariant)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_fromCompletedCall__Ljava_lang_Object_2)
(JNIEnv *__jni_env,
 jclass,
 jobject returnValue0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QRemoteObjectPendingCall::fromCompletedCall(QVariant)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QVariant __qt_returnValue0 = qtjambi_cast<QVariant>(__jni_env, returnValue0);
        QRemoteObjectPendingCall __qt_return_value = QRemoteObjectPendingCall::fromCompletedCall(__qt_returnValue0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QRemoteObjectPendingCall_00024Impl_clone_1native)
(JNIEnv *__jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QRemoteObjectPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QRemoteObjectPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QRemoteObjectPendingCall(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceValueTypeInfo<QRemoteObjectPendingCall>("QRemoteObjectPendingCall", "io/qt/remoteobjects/QRemoteObjectPendingCall");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QRemoteObjectPendingCall, {
        ConstructorInfo(&__qt_construct_QRemoteObjectPendingCall, nullptr)
       ,ConstructorInfo(&__qt_construct_QRemoteObjectPendingCall_cref_QRemoteObjectPendingCall, "Lio/qt/remoteobjects/QRemoteObjectPendingCall;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QRemoteObjectPendingCall);
    registerMetaType<QRemoteObjectPendingCall>("QRemoteObjectPendingCall");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QRemoteObjectPendingCall::Error>("QRemoteObjectPendingCall::Error", "io/qt/remoteobjects/QRemoteObjectPendingCall$Error");
// END: enums and flags
}
